@@ -9,7 +9,6 @@ import datetime
 import os
 from pathlib import Path
 from typing import Dict, List, Optional, Tuple, Union
-from sys import getsizeof
 
 import git
 from lxml import etree
@@ -508,6 +507,25 @@ class SeEpub:
 
 			file_css = regex.sub(r"\s*@(charset|namespace).+?;\s*", "\n", file_css).strip()
 
+			# Convert background-image URLs (from local.css only) to base64
+			if filename == "local.css":
+				for image in regex.finditer(pattern=r"""url\("(.+?\.(?:svg|png|jpg))"\)""", string=file_css):
+					image_path = image.captures(1)[0].replace("../", "")
+
+					with open(self.content_path / image_path, "rb") as binary_file:
+						image_contents_base64 = base64.b64encode(binary_file.read()).decode()
+
+					if image_path.endswith(".svg"):
+						replacement = f"""url("data:image/svg+xml;base64,{image_contents_base64}")"""
+					elif image_path.endswith(".jpg"):
+						replacement = f"""url("data:image/jpg;base64,{image_contents_base64}")"""
+					elif image_path.endswith(".png"):
+						replacement = f"""url("data:image/png;base64,{image_contents_base64}")"""
+					else:
+						continue
+
+					file_css = file_css.replace(image.group(0), replacement)
+
 			css = css + f"\n\n\n/* {filepath.name} */\n" + file_css
 
 		css = css.strip()
@@ -615,12 +633,7 @@ class SeEpub:
 		output_xhtml = output_dom.to_string()
 
 		# All done, clean the output
-		# Very large files like Ulysses S. Grant's memoirs or Through the Looking Glass will crash lxml due to their size.
-		# The inlined SVGs get too big.
-		# So, if the byte size of the XHTML string is larger than an arbitrary size, don't pretty print the output.
-		# Pepys is about 20,000,000 bytes
-		if getsizeof(output_xhtml) < 100000000:
-			output_xhtml = se.formatting.format_xhtml(output_xhtml)
+		output_xhtml = se.formatting.format_xhtml(output_xhtml)
 
 		# Insert our CSS. We do this after `clean` because `clean` will escape > in the CSS
 		output_xhtml = regex.sub(r"<style/>", "<style><![CDATA[\n\t\t\t" + css + "\t\t]]></style>", output_xhtml)
@@ -1245,7 +1258,7 @@ class SeEpub:
 		with open(self.endnotes_path, "w") as file:
 			file.write(endnotes_dom.to_string())
 
-	def generate_endnotes(self) -> Tuple[int, int]:
+	def generate_endnotes(self) -> Tuple[int, int, list]:
 		"""
 		Read the epub spine to regenerate all endnotes in order of appearance, starting from 1.
 		Changes are written to disk.
@@ -1316,7 +1329,7 @@ class SeEpub:
 			with open(self.endnotes_path, "w") as file:
 				file.write(se.formatting.format_xhtml(endnotes_dom.to_string()))
 
-		return current_note_number - 1, notes_changed
+		return current_note_number - 1, notes_changed, change_list
 
 	def __process_link(self, change_list, current_note_number, file_name, link, needs_rewrite, notes_changed) -> Tuple[bool, int]:
 		"""
@@ -1335,7 +1348,7 @@ class SeEpub:
 
 		new_anchor = f"note-{current_note_number:d}"
 		if new_anchor != old_anchor:
-			change_list.append(f"Changed {old_anchor} to {new_anchor} in {file_name}")
+			change_list.append(f"{old_anchor}->{new_anchor}, {file_name}")
 			notes_changed += 1
 			# Update the link in the dom
 			link.set_attr("href", f"{self.endnotes_path.name}#{new_anchor}")
