@@ -178,7 +178,7 @@ def build(self, run_epubcheck: bool, check_only: bool, build_kobo: bool, build_k
 		if proof:
 			with open(work_compatible_epub_dir / "epub" / "css" / "local.css", "a", encoding="utf-8") as local_css_file:
 				with importlib_resources.open_text("se.data.templates", "proofreading.css", encoding="utf-8") as proofreading_css_file:
-					local_css_file.write(proofreading_css_file.read())
+					local_css_file.write("\n" + proofreading_css_file.read())
 
 		# Update the release date in the metadata and colophon
 		if self.last_commit:
@@ -292,10 +292,17 @@ def build(self, run_epubcheck: bool, check_only: bool, build_kobo: bool, build_k
 
 				# We've already replaced attribute/namespace selectors with classes in the CSS, now add those classes to the matching elements
 				if regex.search(r"\[[a-z]+\|[a-z]+", selector):
-					for namespace_selector in regex.findall(r"\[[a-z]+\|[a-z]+(?:\~\=\"[^\"]*?\")?\]", selector):
+					for namespace_selector in regex.findall(r"\[[a-z]+\|[a-z]+(?:[\~\^\|\$\*]?\=\"[^\"]*?\")?\]", selector):
 						new_class = regex.sub(r"^\.", "", se.formatting.namespace_to_class(namespace_selector))
 
 						for element in dom.css_select(namespace_selector):
+							# If we're targeting xml:lang attributes, never add the class to `<html>` or `<body>`.
+							# We were most likely targeting `body [xml|lang]` but since by default we add classes to
+							# everything, that could result in `<html>` getting the `xml-lang` class and making everything
+							# italics.
+							if namespace_selector == "[xml|lang]" and element.tag in ("html", "body"):
+								continue
+
 							current_class = element.get_attr("class") or ""
 
 							if new_class not in current_class:
@@ -480,7 +487,6 @@ def build(self, run_epubcheck: bool, check_only: bool, build_kobo: bool, build_k
 						else:
 							node.set_attr("role", f"doc-{attr_values[0]}")
 
-
 				# We converted svgs to pngs, so replace references
 				for node in dom.xpath("/html/body//img[re:test(@src, '\\.svg$')]"):
 					src = node.get_attr("src")
@@ -530,6 +536,7 @@ def build(self, run_epubcheck: bool, check_only: bool, build_kobo: bool, build_k
 				processed_xhtml = processed_xhtml.replace("〃", "“")
 				processed_xhtml = processed_xhtml.replace(" ", f"{se.NO_BREAK_SPACE}{se.NO_BREAK_SPACE}") # em-space to two nbsps
 				processed_xhtml = processed_xhtml.replace("∶", ":")
+				processed_xhtml = processed_xhtml.replace("℅", "c/o")
 
 				# Replace combining vertical line above, used to indicate stressed syllables, with combining acute accent
 				processed_xhtml = processed_xhtml.replace(fr"{se.COMBINING_VERTICAL_LINE_ABOVE}", fr"{se.COMBINING_ACUTE_ACCENT}")
@@ -579,6 +586,9 @@ def build(self, run_epubcheck: bool, check_only: bool, build_kobo: bool, build_k
 					# Replace `vw` or `vh` units with percent, a reasonable approximation
 					processed_css = regex.sub(r"([0-9\.]+\s*)v(w|h);", r"\1%;", processed_css)
 
+					# We converted svgs to pngs, so replace references
+					processed_css = regex.sub(r"""url\("(.*?)\.svg"\)""", r"""url("\1.png")""", processed_css)
+
 					if processed_css != css:
 						file.seek(0)
 						file.write(processed_css)
@@ -622,6 +632,14 @@ def build(self, run_epubcheck: bool, check_only: bool, build_kobo: bool, build_k
 					# for node in dom.xpath("/html/body//span[contains(@class, 'quote-align')]"):
 					# 	node.unwrap()
 
+					# Inserted koboSpans do not play nicely with our default poetry CSS, which target all spans.
+					# Mark up original verse spans with 'kobo-verse-span' to make the poetry CSS more specific.
+					for node in dom.xpath("/html/body//*[contains(@epub:type, 'z3998:poem') or contains(@epub:type, 'z3998:verse') or contains(@epub:type, 'z3998:song') or contains(@epub:type, 'z3998:hymn')]//p[not(text()[normalize-space() != ''])]/span"):
+						if node.get_attr("class"):
+							node.set_attr("class", node.get_attr("class") + " kobo-verse-span")
+						else:
+							node.set_attr("class", "kobo-verse-span")
+
 					# Change 'noteref' to 'endnote' so that popup endnotes work in Kobo. Kobo doesn't understand 'noteref', only 'endnote'.
 					for node in dom.xpath("/html/body//a[contains(@epub:type, 'noteref')]"):
 						node.set_attr("epub:type", node.get_attr("epub:type") + " endnote")
@@ -667,6 +685,21 @@ def build(self, run_epubcheck: bool, check_only: bool, build_kobo: bool, build_k
 					with open(file_path, "w", encoding="utf-8") as file:
 						file.write(xhtml)
 
+				if file_path.suffix == ".css":
+					with open(file_path, "r+", encoding="utf-8") as file:
+						css = file.read()
+						processed_css = css
+
+						# Instead of targeting all spans with poetry CSS, only target proper verse spans (not inserted koboSpans)
+						processed_css = regex.sub(r"""(\.epub-type-z3998-(poem|verse|song|hymn)(.*))span(?![[.])""", r"""\1span.kobo-verse-span""", processed_css)
+						# Indentation selectors need to be more specific as well to compensate
+						processed_css = regex.sub(r"""p span\.i\d+""", r"""\g<0>.kobo-verse-span""", processed_css)
+
+						if processed_css != css:
+							file.seek(0)
+							file.write(processed_css)
+							file.truncate()
+
 			# All done, clean the output
 			# Note that we don't clean .xhtml files, because the way kobo spans are added means that it will screw up spaces inbetween endnotes.
 			for file_path in work_kepub_dir.glob("**/*.opf"):
@@ -1220,7 +1253,7 @@ def build(self, run_epubcheck: bool, check_only: bool, build_kobo: bool, build_k
 			# Include compatibility CSS
 			with open(work_compatible_epub_dir / "epub" / "css" / "core.css", "a", encoding="utf-8") as core_css_file:
 				with importlib_resources.open_text("se.data.templates", "kindle.css", encoding="utf-8") as compatibility_css_file:
-					core_css_file.write(compatibility_css_file.read())
+					core_css_file.write("\n" + compatibility_css_file.read())
 
 			# Build an epub file we can send to Calibre
 			se.epub.write_epub(work_compatible_epub_dir, work_dir / compatible_epub_output_filename)
