@@ -15,7 +15,7 @@ def get_xhtml_language(xhtml: str) -> str:
 	Try to get the IETF lang tag for a complete XHTML document
 	"""
 
-	supported_languages = ["en-US", "en-GB", "en-AU", "en-CA"]
+	supported_languages = ["en-US", "en-GB", "en-AU", "en-CA", "en-IE"]
 
 	match = regex.search(r"<html[^>]+?xml:lang=\"([^\"]+)\"", xhtml)
 
@@ -137,7 +137,7 @@ def modernize_spelling(xhtml: str) -> str:
 	xhtml = regex.sub(r"\b([Oo])ker\b", r"\1cher", xhtml)				# oker -> ocher
 	xhtml = regex.sub(r"\b([Ww])ellnigh\b", r"\1ell-nigh", xhtml)			# wellnigh -> well-nigh
 	xhtml = regex.sub(r"\b([Tt]he|[Aa]nd|[Oo]r) what not(?! to)\b", r"\1 whatnot", xhtml)	# what not -> whatnot
-	xhtml = regex.sub(r"\b([Gg])ood[\-]?bye?\b", r"\1oodbye", xhtml)			# good-by -> goodbye
+	xhtml = regex.sub(r"\b([Gg])ood[\-]?bye?\b", r"\1oodbye", xhtml)		# good-by -> goodbye
 	xhtml = regex.sub(r"\b([Gg])ood\sbye\b", r"\1oodbye", xhtml)			# good bye -> goodbye (Note that we can't do `good by` -> `goodby` because one might do good by someone.
 	xhtml = regex.sub(r"\b([Gg])ood[\-\s]?bye?s\b", r"\1oodbyes", xhtml)		# good bys -> goodbyes
 	xhtml = regex.sub(r"\b([Hh])ind(u|oo)stanee", r"\1industani", xhtml)		# hindoostanee -> hindustani
@@ -152,8 +152,8 @@ def modernize_spelling(xhtml: str) -> str:
 	xhtml = regex.sub(r"\bindorse", r"endorse", xhtml)				# indorse -> endorse
 	xhtml = regex.sub(r"\bIntrust", r"Entrust", xhtml)				# Intrust -> Entrust
 	xhtml = regex.sub(r"\bintrust", r"entrust", xhtml)				# intrust -> entrust
-	xhtml = regex.sub(r"\bPhantasies", r"Fantasies", xhtml)			# Phantasies -> Fantasies
-	xhtml = regex.sub(r"\bphantasies", r"fantasies", xhtml)			# phantasies -> fantasies
+	xhtml = regex.sub(r"\bPhantasies", r"Fantasies", xhtml)				# Phantasies -> Fantasies
+	xhtml = regex.sub(r"\bphantasies", r"fantasies", xhtml)				# phantasies -> fantasies
 	xhtml = regex.sub(r"\bPhantas(y|ie)", r"Fantasy", xhtml)			# Phantasie -> Fantasy
 	xhtml = regex.sub(r"\bphantas(y|ie)", r"fantasy", xhtml)			# phantasie -> fantasy
 	xhtml = regex.sub(r"\bPhantastic", r"Fantastic", xhtml)				# Phantastic -> Fantastic
@@ -185,7 +185,7 @@ def modernize_spelling(xhtml: str) -> str:
 	xhtml = regex.sub(r"\b([Cc])oërc", r"\1oerc", xhtml)				# coërc -> coerc (as in coërcion)
 	xhtml = regex.sub(r"\b([Cc])oëd", r"\1oed", xhtml)				# coëd -> coed (as in coëducation)
 	xhtml = regex.sub(r"\b([Dd])aïs\b", r"\1ais", xhtml)				# daïs -> dais
-	xhtml = regex.sub(r"\b([Cc])oup\-de\-grace", r"\1oup-de-grâce", xhtml)		# coup-de-grace -> coup-de-grâce
+	xhtml = regex.sub(r"\b([Cc])oup[\- ]de[\- ]gr[aâ]ce", r"\1oup de grâce", xhtml)	# coup-de-grace -> coup-de-grâce
 	xhtml = regex.sub(r"\b([Cc])anape", r"\1anapé", xhtml)				# canape -> canapé
 	xhtml = regex.sub(r"\b([Pp])recis\b", r"\1récis", xhtml)			# precis -> précis
 	xhtml = regex.sub(r"\b([Gg])ood\-night", r"\1ood night", xhtml)			# good-night -> good night
@@ -198,7 +198,7 @@ def modernize_spelling(xhtml: str) -> str:
 	xhtml = regex.sub(r"\beclat\b", r"éclat", xhtml)				# eclat -> éclat
 	xhtml = regex.sub(r"\ba la\b", r"à la", xhtml)					# a la -> à la
 	xhtml = regex.sub(r"\ba propos\b", r"apropos", xhtml)				# a propos -> apropos
-	xhtml = regex.sub(r"\bper cent(s|ages?)?\b", r"percent\1", xhtml)			# per cent -> percent
+	xhtml = regex.sub(r"\bper cent(s|ages?)?\b", r"percent\1", xhtml)		# per cent -> percent
 	xhtml = regex.sub(r"\bpercent\.(\s+[\p{Lowercase_Letter}])", r"percent\1", xhtml)		# percent. followed by lowercase -> percent
 	xhtml = regex.sub(r"\bpercent\.[,;:\!\?]", r"percent,", xhtml)			# per cent. -> percent
 	xhtml = regex.sub(r"\b([Ee])ntree(s?)\b", r"\1ntrée\2", xhtml)			# entree -> entrée
@@ -235,7 +235,7 @@ def modernize_spelling(xhtml: str) -> str:
 	xhtml = regex.sub(r"\b([Dd])ulness", r"\1ullness", xhtml)			# dulness -> dullness
 	xhtml = regex.sub(r"\b([Ff])iord", r"\1jord", xhtml)				# fiord -> fjord
 	xhtml = regex.sub(r"\b([Ff])ulness\b", r"\1ullness", xhtml)			# fulness -> fullness (but not for ex. thoughtfulness)
-	xhtml = regex.sub(r"['’]([Pp])hone", r"\1hone", xhtml)				# ’phone -> phone; note that we can't use \b on the left because it won't match for some reason
+	xhtml = regex.sub(r"['’]([Pp])hon(e|ing)", r"\1hon\2", xhtml)			# ’phone -> phone; note that we can't use \b on the left because it won't match for some reason
 	xhtml = regex.sub(r"\b([Ss])hew", r"\1how", xhtml)				# shew -> show
 	xhtml = regex.sub(r"\b([Tt])rowsers", r"\1rousers", xhtml)			# trowsers -> trousers
 	xhtml = regex.sub(r"([Bb])iass", r"\1ias", xhtml)				# (un)biass(ed) -> (un)bias(ed)
@@ -253,7 +253,7 @@ def modernize_spelling(xhtml: str) -> str:
 	xhtml = regex.sub(r"\b([Ss])ate\b", r"\1at", xhtml)				# sate -> sat
 	xhtml = regex.sub(r"\b([Aa])ttache\b", r"\1ttaché", xhtml)			# attache -> attaché
 	xhtml = regex.sub(r"\b([Pp])orte[\- ]coch[eè]re\b", r"\1orte-cochère", xhtml)	# porte-cochere -> porte-cochère
-	xhtml = regex.sub(r"\b([Nn])[eé]glig[eé]e?(s?)\b", r"\1egligee\2", xhtml)		# négligée -> negligee
+	xhtml = regex.sub(r"\b([Nn])[eé]glig[eé]e?(s?)\b", r"\1egligee\2", xhtml)	# négligée -> negligee
 	xhtml = regex.sub(r"\b([Ss])hort cut(s?)\b", r"\1hortcut\2", xhtml)		# short cut -> shortcut
 	xhtml = regex.sub(r"\b([Ff])ocuss", r"\1ocus", xhtml)				# focuss -> focus
 	xhtml = regex.sub(r"\b([Mm])ise[ \-]en[ \-]sc[eè]ne", r"\1ise-en-scène", xhtml)	# mise en scene -> mise-en-scène
@@ -269,14 +269,14 @@ def modernize_spelling(xhtml: str) -> str:
 	xhtml = regex.sub(r"\b([Pp])ere\b", r"\1ère", xhtml)				# pere -> père (e.g. père la chaise)
 	xhtml = regex.sub(r"\b([Tt])able(s?) d’hote\b", r"\1able\2 d’hôte", xhtml)	# table d'hote -> table d'hôte
 	xhtml = regex.sub(r"\b([Ee])au(x?)[ \-]de[ \-]vie\b", r"\1au\2-de-vie", xhtml)	# eau de vie -> eau-de-vie
-	xhtml = regex.sub(r"\b3d\b", r"3rd", xhtml)						# 3d -> 3rd (warning: check that we don't convert 3d in the "3 pence" sense!)
-	xhtml = regex.sub(r"\b2d\b", r"2nd", xhtml)						# 2d -> 2nd (warning: check that we don't convert 2d in the "2 pence" sense!)
+	xhtml = regex.sub(r"\b3d\b", r"3rd", xhtml)					# 3d -> 3rd (warning: check that we don't convert 3d in the "3 pence" sense!)
+	xhtml = regex.sub(r"\b2d\b", r"2nd", xhtml)					# 2d -> 2nd (warning: check that we don't convert 2d in the "2 pence" sense!)
 	xhtml = regex.sub(r"\b([Mm])ia[uo]w", r"\1eow", xhtml)				# miauw, miaow -> meow
 	xhtml = regex.sub(r"\b([Cc])aviare", r"\1aviar", xhtml)				# caviare -> caviar
 	xhtml = regex.sub(r"\b([Ss])ha’n’t", r"\1han’t", xhtml)				# sha'n't -> shan't (see https://english.stackexchange.com/questions/71414/apostrophes-in-contractions-shant-shant-or-shant)
 	xhtml = regex.sub(r"\b([Ss])[uû]ret[eé]", r"\1ûreté", xhtml)			# Surete -> Sûreté
 	xhtml = regex.sub(r"\b([Ss])eance", r"\1éance", xhtml)				# seance -> séance
-	xhtml = regex.sub(r"\b([Ff])in[\- ]de[\- ]siecle", r"\1in de siècle", xhtml)		# fin de siecle -> fin de siècle
+	xhtml = regex.sub(r"\b([Ff])in[\- ]de[\- ]siecle", r"\1in de siècle", xhtml)	# fin de siecle -> fin de siècle
 	xhtml = regex.sub(r"\bEmpale", r"Impale", xhtml)				# Empale -> Impale
 	xhtml = regex.sub(r"\bempale", r"impale", xhtml)				# empale -> impale
 	xhtml = regex.sub(r"\b([Tt])abu(s?)\b", r"\1aboo\2", xhtml)			# tabu -> taboo
@@ -299,7 +299,7 @@ def modernize_spelling(xhtml: str) -> str:
 	xhtml = regex.sub(r"\b([Cc])ourtezan", r"\1ourtesan", xhtml)			# courtezan -> courtesan
 	xhtml = regex.sub(r"\b([Cc])ompleate?", r"\1omplete", xhtml)			# compleat -> complete
 	xhtml = regex.sub(r"\b([Dd])umfound", r"\1umbfound", xhtml)			# dumfound -> dumbfound
-	xhtml = regex.sub(r"\b’([Cc])ello(s?)\b", r"\1ello\2", xhtml)			# 'cello -> cello
+	xhtml = regex.sub(r"’([Cc])ello(s?)\b", r"\1ello\2", xhtml)			# 'cello -> cello
 	xhtml = regex.sub(r"\bwelsh (rarebit|rabbit)\b", r"Welsh \1", xhtml)		# welsh rarebit/rabbit -> Welsh rarebit/rabbit
 	xhtml = regex.sub(r"\b([Yy])our self\b(?!-)", r"\1ourself", xhtml)		# your self -> your self, but ignore constructs like `your self-determination` or `your selfish sister`.
 	xhtml = regex.sub(r"\b([Aa])ny how\b", r"\1nyhow", xhtml)			# any how -> anyhow
@@ -326,7 +326,7 @@ def modernize_spelling(xhtml: str) -> str:
 	xhtml = regex.sub(r"\b([Dd])ivers\b", r"\1iverse", xhtml)			# divers -> diverse
 	xhtml = regex.sub(r"\b([Ll])anthorn", r"\1antern", xhtml)			# lanthorn -> lantern
 	xhtml = regex.sub(r"\b([Oo])rgie\b", r"\1rgy", xhtml)				# orgie -> orgy
-	xhtml = regex.sub(r"\b([Oo])u?rang-[Oo]utang?", r"\1rangutan", xhtml)		# ourang-outang -> orangutan
+	xhtml = regex.sub(r"\b([Oo])u?rang[\s-][Oo]utang?", r"\1rangutan", xhtml)	# ourang-outang -> orangutan
 	xhtml = regex.sub(r"(?<!-)\b([Ss])o\sand\s([Ss])o\b(?!-)", r"\1o-and-\2o", xhtml)		# so and so -> so-and-so; ignore `so-and-so and so-and-so`
 	xhtml = regex.sub(r"\b([Cc])añon", r"\1anyon", xhtml)				# cañon -> canyon
 	xhtml = regex.sub(r"\b([Kk])vas\b", r"\1vass", xhtml)				# kvas -> kvass
@@ -352,7 +352,7 @@ def modernize_spelling(xhtml: str) -> str:
 	xhtml = regex.sub(r"\b([Ss])pung", r"\1pong", xhtml)				# spung(e|ing|y) -> sponge
 	xhtml = regex.sub(r"\b([Ww])oful", r"\1oeful", xhtml)				# woful -> woeful
 	xhtml = regex.sub(r"\b([Hh]e|[Ss]he|[Yy]ou|[Tt]hey)’ld", r"\1’d", xhtml)	# he'ld, she'ld, you'ld, they'ld -> he'd, she'd, you'd, they'd
-	xhtml = regex.sub(r"\b([Ii])n the mean time", r"\1n the meantime", xhtml)	# in the mean time -> in the meantime
+	xhtml = regex.sub(r"\b([Mm])ean time", r"\1eantime", xhtml)			# mean time -> meantime
 	xhtml = regex.sub(r"\b([Ch])huck[\- ]full\b", r"\1ock-full", xhtml)		# chuck-full -> chock-full
 	xhtml = regex.sub(r"\b([Pp])rythee\b", r"\1rithee", xhtml)			# prythee -> prithee
 	xhtml = regex.sub(r"\b([Hh])av’n’t", r"\1aven’t", xhtml)			# hav’n’t -> haven’t
@@ -361,10 +361,38 @@ def modernize_spelling(xhtml: str) -> str:
 	xhtml = regex.sub(r"\b([Ii])kon(s?)\b", r"\1con\2", xhtml)			# ikon -> icon
 	xhtml = regex.sub(r"\b([Pp])remiss\b", r"\1remise", xhtml)			# premiss -> premise
 	xhtml = regex.sub(r"\b([Pp])remisses", r"\1remises", xhtml)			# premisses -> premises
+	xhtml = regex.sub(r"\b([Rr])icketty", r"\1ickety", xhtml)			# ricketty -> rickety
+	xhtml = regex.sub(r"\b([Dd])[ié]shabille", r"\1eshabille", xhtml)		# déshabille -> deshabille
+	xhtml = regex.sub(r"\b([Mm])ollah", r"\1ullah", xhtml)				# mollah -> mullah
+	xhtml = regex.sub(r"\b([Ss])opha(s?)\b", r"\1opha\2", xhtml)			# sopha -> sofa
+	xhtml = regex.sub(r"\b([Oo])dalisk", r"\1dalisque", xhtml)			# odalisk -> odalisque
+	xhtml = regex.sub(r"\b([Ss])cissar", r"\1cissor", xhtml)			# scissar -> scissor
+	xhtml = regex.sub(r"\b([Aa])lmanack", r"\1lmanac", xhtml)			# almanack -> almanac
+	xhtml = regex.sub(r"\b([Nn])egociation", r"\1egotiation", xhtml)		# negociation -> negotiation
+	xhtml = regex.sub(r"Incumber", r"Encumber", xhtml)				# incumber -> encumber
+	xhtml = regex.sub(r"incumber", r"encumber", xhtml)				# incumber -> encumber
+	xhtml = regex.sub(r"\bCadi\b", r"Qadi", xhtml)					# cadi -> qadi
+	xhtml = regex.sub(r"\bcadi\b", r"qadi", xhtml)					# cadi -> qadi
+	xhtml = regex.sub(r"\b([Pp])edler", r"\1eddler", xhtml)				# pedler -> peddler
+	xhtml = regex.sub(r"\b([Cc])aldron(s?)", r"\1auldron\2", xhtml)			# caldron -> cauldron
+	xhtml = regex.sub(r"\b([Tt])hru\b", r"\1hru", xhtml)				# thru -> through
+	xhtml = regex.sub(r"\b[‘’]([Ss])cope(s?)\b", r"\1cope\2", xhtml)		# 'scope -> scope
+	xhtml = regex.sub(r"\b([Ff])(aqu?ir|akeer)", r"\1akir", xhtml)			# faqir, fakeer -> fakir
+	xhtml = regex.sub(r"\b([Ii])maum", r"\1mam", xhtml)				# imaum -> imam
+	xhtml = regex.sub(r"\b([Mm])oujik", r"\1uzhik", xhtml)				# moujik -> muzhik
+	xhtml = regex.sub(r"\b([Cc])har[ -][aà][ -]banc", r"\1arabanc", xhtml)		# char-à-banc -> charabanc
+	xhtml = regex.sub(r"’([Cc])ellist", r"\1ellist", xhtml)				# 'cellist -> cellist
+	xhtml = regex.sub(r"([Pp])ourtray", r"\1ortray", xhtml)				# pourtray -> portray
+	xhtml = regex.sub(r"([S])toopid", r"\1tupid", xhtml)				# stoopid -> stupid
+	xhtml = regex.sub(r"([S])uède", r"\1uede", xhtml)				# suède -> suede
+	xhtml = regex.sub(r"([Ff])or ever\b",r"\1orever", xhtml)			# for ever -> forever
+	xhtml = regex.sub(r"([Dd])ébris\b", r"\1ebris", xhtml)				# débris -> debris
+	xhtml = regex.sub(r"\b([Tt])ho['’]\b", r"\1hough", xhtml)			# tho' -> though
 
 	# Normalize some names
 	xhtml = regex.sub(r"Moliere", r"Molière", xhtml)				# Moliere -> Molière
 	xhtml = regex.sub(r"Tolstoi", r"Tolstoy", xhtml)				# Tolstoi -> Tolstoy
+	xhtml = regex.sub(r"Dostoi?e(v|ff)sky", r"Dostoevsky", xhtml)			# Dostoievsky -> Dostoevsky
 	xhtml = regex.sub(r"Buonaparte", r"Bonaparte", xhtml)				# Buonaparte -> Bonaparte
 	xhtml = regex.sub(r"Shake?spea?r([^ie])", r"Shakespeare\1", xhtml)		# Shakespear/Shakspeare -> Shakespeare
 	xhtml = regex.sub(r"Shake?spea?re", r"Shakespeare", xhtml)			# Shakespear/Shakspeare -> Shakespeare
@@ -385,15 +413,15 @@ def modernize_spelling(xhtml: str) -> str:
 	xhtml = regex.sub(r"\bTokio", r"Tokyo", xhtml)					# Tokio -> Tokyo
 	xhtml = regex.sub(r"\bTchekh?ov", r"Chekhov", xhtml)				# Tchekhov -> Chekhov
 	xhtml = regex.sub(r"\bVereshtchagin", r"Vereshchagin", xhtml)			# Vereshtchagin -> Vereshchagin
-	xhtml = regex.sub(r"\bSoudan", "Sudan", xhtml)					# Soudan -> Sudan
-	xhtml = regex.sub(r"\bJack-in-the-box", "jack-in-the-box", xhtml)		# Jack-in-the-box -> jack-in-the-box
+	xhtml = regex.sub(r"\bSoudan", r"Sudan", xhtml)					# Soudan -> Sudan
+	xhtml = regex.sub(r"\bJack-in-the-box", r"jack-in-the-box", xhtml)		# Jack-in-the-box -> jack-in-the-box
 	xhtml = regex.sub(r"\bServia", r"Serbia", xhtml)				# Servia(n) -> Serbia(n)
 	xhtml = regex.sub(r"\bEsquimaux?\b", r"Eskimo", xhtml)				# Esquimau -> Eskimo
 	xhtml = regex.sub(r"\bLaocoon", r"Laocoön", xhtml)				# Lacoon -> Laocoön
-	xhtml = regex.sub(r"Porto Rico", "Puerto Rico", xhtml)				# Porto Rico -> Puerto Rico
-	xhtml = regex.sub(r"Mahomet", "Muhammad", xhtml)				# Mahomet -> Muhammad
-	xhtml = regex.sub(r"M[ao]hommed", "Muhammad", xhtml)		        	# Mahommed -> Muhammad
-	xhtml = regex.sub(r"Esthonian", "Estonian", xhtml)				# Esthonian -> Estonian
+	xhtml = regex.sub(r"Porto Rico", r"Puerto Rico", xhtml)				# Porto Rico -> Puerto Rico
+	xhtml = regex.sub(r"Mahomet", r"Muhammad", xhtml)				# Mahomet -> Muhammad
+	xhtml = regex.sub(r"M[ao]hommed", r"Muhammad", xhtml)		        	# Mahommed -> Muhammad
+	xhtml = regex.sub(r"Esthonian", r"Estonian", xhtml)				# Esthonian -> Estonian
 	xhtml = regex.sub(r"\b([Ss])anscrit\b", r"\1anskrit", xhtml)			# Sanscrit -> Sanskrit
 	xhtml = regex.sub(r"Francois", r"François", xhtml)				# Francois -> François
 	xhtml = regex.sub(r"Hayti(\b|an\b)", r"Haiti\1", xhtml)				# Hayti -> Haiti
@@ -408,26 +436,27 @@ def modernize_spelling(xhtml: str) -> str:
 	xhtml = regex.sub(r"jesuit", r"Jesuit", xhtml)					# jesuit -> Jesuit
 	xhtml = regex.sub(r"Roman catholic", r"Roman Catholic", xhtml)			# Roman catholic -> Roman Catholic; Note that we can't uppercase `catholic` in the generic sense because `catholic` can mean "worldly"
 	xhtml = regex.sub(r"Burmah", r"Burma", xhtml)					# Burmah -> Burma
+	xhtml = regex.sub(r"Turgenieff", r"Turgenev", xhtml)				# Turgenieff -> Turgenev
 
 	# Remove archaic diphthongs
 	xhtml = regex.sub(r"\b([Mm])edi(æ|ae)val", r"\1edieval", xhtml)
-	xhtml = xhtml.replace("Cæsar", "Caesar")
-	xhtml = xhtml.replace("Crœsus", "Croesus")
-	xhtml = xhtml.replace("\bæon\b", "aeon")
-	xhtml = xhtml.replace("\bÆon\b", "Aeon")
-	xhtml = xhtml.replace("Æneas", "Aeneas")
-	xhtml = xhtml.replace("Æneid", "Aeneid")
-	xhtml = xhtml.replace("Æschylus", "Aeschylus")
-	xhtml = xhtml.replace("æsthet", "aesthet") # aesthetic, aesthete, etc.
-	xhtml = xhtml.replace("Æsthet", "Aesthet") # Aesthetic, Aesthete, etc.
+	xhtml = xhtml.replace("Cæsar", r"Caesar")
+	xhtml = xhtml.replace("Crœsus", r"Croesus")
+	xhtml = xhtml.replace("\bæon\b", r"aeon")
+	xhtml = xhtml.replace("\bÆon\b", r"Aeon")
+	xhtml = xhtml.replace("Æneas", r"Aeneas")
+	xhtml = xhtml.replace("Æneid", r"Aeneid")
+	xhtml = xhtml.replace("Æschylus", r"Aeschylus")
+	xhtml = xhtml.replace("æsthet", r"aesthet") # aesthetic, aesthete, etc.
+	xhtml = xhtml.replace("Æsthet", r"Aesthet") # Aesthetic, Aesthete, etc.
 	xhtml = regex.sub(r"\b([Hh])yæna", r"\1yena", xhtml)
 	xhtml = regex.sub(r"\b([Ll])arvæ", r"\1arvae", xhtml)
-	xhtml = xhtml.replace("Œdip", "Oedip") # Oedipus, Oedipal
+	xhtml = xhtml.replace("Œdip", r"Oedip") # Oedipus, Oedipal
 	xhtml = regex.sub(r"\b([Pp])æan", r"\1aean", xhtml)
 	xhtml = regex.sub(r"\b([Vv])ertebræ", r"\1ertebrae", xhtml)
 
 	# Remove spaces before contractions like `n’t` e.g. `is n’t` -> `isn’t`
-	xhtml = regex.sub(r" n’t\b", "n’t", xhtml)
+	xhtml = regex.sub(r" n’t\b", r"n’t", xhtml)
 
 	# Remove spaces before contractions like `it 'll`
 	xhtml = regex.sub(r"([\p{Letter}])\s[‘’]ll\b", r"\1’ll", xhtml)
@@ -447,8 +476,8 @@ def modernize_spelling(xhtml: str) -> str:
 	if language in ["en-US", "en-CA"]:
 		xhtml = regex.sub(r"\b([Cc])osey", r"\1ozy", xhtml)
 
-	# Australian spelling follows GB
-	if language in ["en-GB", "en-AU"]:
+	# Australian and Irish spelling follows GB
+	if language in ["en-GB", "en-AU", "en-IE"]:
 		xhtml = regex.sub(r"\b([Cc])osey", r"\1osy", xhtml)
 
 	# US spelling is unique
